@@ -13,7 +13,13 @@ is_gnome() {
     dbus-send --print-reply --dest=org.gnome.Shell /org/gnome/Shell org.freedesktop.DBus.Properties.Get string:org.gnome.Shell string:ShellVersion >/dev/null 2>&1
 }
 
-if is_gnome; then
+is_cosmic() {
+  command -v cosmic-osd >/dev/null && [ "$XDG_SESSION_DESKTOP" = "COSMIC" ]
+}
+
+if is_cosmic; then
+  cosmic-osd shutdown
+elif is_gnome; then
   gnome-session-quit --power-off
 elif command -v systemctl >/dev/null; then
   systemctl poweroff
